unit Main;

interface

uses
  SysUtils, Windows, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls, Menus, ComCtrls,
  ICMP, BWGraphs, SiteMan;

type
  TMainForm = class(TForm)
    MainMenu: TMainMenu;
    GraphAddItem: TMenuItem;
    GraphRemoveItem: TMenuItem;
    FileExitItem: TMenuItem;
    HelpAboutItem: TMenuItem;
//    FormPlace: TFormPlacement;
//    xApplication: TxApplication;
    Pages: TPageControl;
    Timer: TTimer;
    PropItem: TMenuItem;
    procedure FileExit(Sender: TObject);
    procedure HelpAbout(Sender: TObject);
    procedure GraphAddItemClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure GraphRemoveItemClick(Sender: TObject);
    procedure TimerTimer(Sender: TObject);
    procedure PropItemClick(Sender: TObject);
   protected
    SiteList : TList;
    ShutDown : boolean;
  end;

var
  MainForm: TMainForm;

implementation

uses frmList, About, frmProp;

{$R *.DFM}

procedure TMainForm.FileExit(Sender: TObject);
var i:integer;
begin
  for i:=0 to SiteList.Count-1 do TSite(SiteList[i]).Shutdown:=true;
  MainForm.Close;
end;

procedure TMainForm.HelpAbout(Sender: TObject);
begin
  AboutBox.ShowModal;
end;

procedure TMainForm.GraphAddItemClick(Sender: TObject);
var S:String;
    IC:TICMP;
    Site : TSite;
    Entry : TDataEntry;
begin
  S:=InputBox('Add host to ping','Please enter the host name or address to ping','');
  if S='' then exit;
  try
   IC:=TICMP.Create;
  except
    On E:TICMPException do
    begin
      MessageBox(0,PChar(E.Message),'BWPing Error',MB_ICONSTOP or MB_OK);
      exit;
    end;
  end;
  IC.Address:=S;
  IC.ResolveAddr;
  if IC.ErrorCode>0 then
  begin
    MessageBox(0,'Failed to resolve the given address','BWPing Error',MB_ICONSTOP or MB_OK);
    Exit;
  end;
  Site := TSite.Create;
  Site.Address := IC.HostIP;
  IC.Free;

  Site.HostName:=S;
  Site.Timeout := 1000;
  Site.DataSize := 56;

  Site.Sheet:=TTabSheet.Create(Pages);
  Site.Sheet.PageControl:=Pages;
  Site.Graph:=TBWGraph.Create(Site.Sheet);
  Site.Sheet.InsertControl(Site.Graph);
  Site.Graph.Align:=alClient;
  Site.Sheet.Caption:=Site.HostName;
  Entry:=Site.Graph.AddEntry;
  Site.Graph.ShowMinMax:=true;
  Site.Graph.ShowLegend:=false;
  Site.Graph.ColumnEntry:=Entry;
  Site.Graph.MinMaxEntry:=Entry;
  Site.Graph.ShowGrid:=true;
  Site.Graph.HGridLines:=5;
  Site.Graph.VGridLines:=20;
  Site.Graph.Color:=clBtnText;
  Site.Graph.LegendBkColor:=clWindow;
  Entry.Color:=clLime;
  Entry.MaxGrid:=100;
  Entry.AutoGrid:=true;
  Site.Start;
  SiteList.Add(Site);
end;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  SiteList:=TList.Create;
end;

procedure TMainForm.FormDestroy(Sender: TObject);
var i:integer;
    Site: TSite;
begin
  ShutDown:=true;
  Screen.Cursor := crHourGlass;
  try
    i:=0;
    while i<SiteList.Count do
    begin
      Site:=TSite(SiteList[0]);
      SiteList.Delete(0);
      Site.Free;
    end;
    SiteList.Free;
  finally
    Screen.Cursor := crDefault;
  end;  // try/finally
end;

procedure TMainForm.GraphRemoveItemClick(Sender: TObject);
var i:integer;
    Site:TSite;
    T:TTabSheet;
begin
  SitesForm.Sites.Items.Clear;
  for i:=0 to SiteList.Count-1 do    // Iterate
    SitesForm.Sites.Items.Add(TSite(SiteList[i]).Address);
  if SitesForm.ShowModal=mrOK then
  begin
    i:=SitesForm.Sites.ItemIndex;
    if i=-1 then exit;
    Site:=TSite(SiteList[i]);
    SiteList.Delete(i);
    Site.Shutdown:=true;
   try
    T:=Site.Sheet;
    Site.Free;
   finally
    T.Free;
   end;
   if Pages.PageCount>0 then Pages.ActivePage:=Pages.Pages[0];
  end;
end;

procedure TMainForm.TimerTimer(Sender: TObject);
var i:integer;
begin
  if ShutDown then exit;
  for i:=0 to SiteList.Count-1 do TSite(SiteList[i]).TimerProc;
end;

procedure TMainForm.PropItemClick(Sender: TObject);
var Sheet : TTabSheet;
    i : integer;
    Site : TSite;
begin
  Sheet:=Pages.ActivePage;
  if Sheet = nil then exit;
  i:=0;
  while TSite(SiteList[i]).Sheet<>Sheet do inc(i);
  if i>=SiteList.Count then exit;
  Site:=TSite(SiteList[i]);
  PropForm.HostLabel.Caption:=Site.Address;
  PropForm.GridCB.Checked:=Site.Graph.ShowGrid;
  PropForm.TimeOutSpin.Value:=Site.Timeout;
  if PropForm.ShowModal = mrCancel then exit;
  Site.Timeout:=Trunc(PropForm.TimeOutSpin.Value);
  Site.Graph.ShowGrid:=PropForm.GridCB.Checked;
end;

end.
